#!/usr/bin/env python
""" jtorx aut 2 cdap aut

  '?COIN_1_1'   ->   'ICOIN !1 !1'
  '!TEA_0_1'    ->   'OTEA !0 !1'

"""
# Author: Harco Kuppens


import sys, re, pprint  # modules from standard lib (python 2.6 and later)

#import efsm    # local module ; next to standard lib modules it uses: pyuppaal module -> locally installed

import yaml
import argparse
import util


def args_parsing(args):
    import os.path
    argparser = argparse.ArgumentParser(prog=os.path.basename(args[0]))

    argparser.add_argument('jtorx_aut_file', help='aut output file (aldebaran format) with labels as expected by jtorx')
    argparser.add_argument('cadp_aut_file', help='aut output file (aldebaran format) with labels as expected by cadp')

    parse_result=argparser.parse_args(args[1:])


    # handle input/output file argument
    cadp_aut_file=os.path.abspath(parse_result.cadp_aut_file).replace('\\','/')
    jtorx_aut_file=os.path.abspath(parse_result.jtorx_aut_file).replace('\\','/')
    # Note: on windows also interprets / as dir sep, and returns path with windows \

    util.check_file_extension(cadp_aut_file,'aut')

    util.check_file_extension(jtorx_aut_file,'aut')
    util.check_isreadablefile(jtorx_aut_file)

    return  [jtorx_aut_file,cadp_aut_file]


# can also be used for tomte_aut2cadp_aut
def jtorx_aut2cadp_aut(infile,outfile):
    """

    """


    f=file(infile)
    lines=f.readlines()

    strings=[lines[0].strip()]

    transitions=lines[1:]

    regexpr_transition=re.compile(r'\s*\(\s*(\d*)\s*,\s*([^,]*)\s*,\s*(\d*)\s*\)')
    for transition in transitions:
        match=regexpr_transition.match(transition)
        if match:
            match=match.groups()
            #label=regexpr_tag.sub('',match[2])
            label=match[1].strip('"').replace('_',' !')

            # next is optional
            if label[0].lower()=='?':
                 label="I"+label[1:]
            else:
                 label="O"+label[1:]

            strings.append("(" + match[0] + "," + '"' + label + '"' +  "," +  match[2] + ")")

    result="\n".join(strings)
    f=open(outfile,'w')
    f.write(result)
    f.close()




def main(args):
    """

    """
    (jtorx_aut_file,cadp_aut_file)=args_parsing(args)
    jtorx_aut2cadp_aut(jtorx_aut_file,cadp_aut_file)



if __name__ == "__main__":
    print main(sys.argv)

